Class: Aws::S3Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::S3Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-s3outposts/client.rb,
sig/client.rbs
Overview
An API client for S3Outposts. To construct a client, you need to configure a :region and :credentials.
client = Aws::S3Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateEndpointResponseSuccess, _ListEndpointsResponseSuccess, _ListOutpostsWithS3ResponseSuccess, _ListSharedEndpointsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResult
Creates an endpoint and associates it with the specified Outpost.
-
#delete_endpoint(params = {}) ⇒ Struct
Deletes an endpoint.
-
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResult
Lists endpoints associated with the specified Outpost.
-
#list_outposts_with_s3(params = {}) ⇒ Types::ListOutpostsWithS3Result
Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services account.
-
#list_shared_endpoints(params = {}) ⇒ Types::ListSharedEndpointsResult
Lists all endpoints associated with an Outpost that has been shared by Amazon Web Services Resource Access Manager (RAM).
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-s3outposts/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
799 800 801 |
# File 'lib/aws-sdk-s3outposts/client.rb', line 799 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
802 803 804 |
# File 'lib/aws-sdk-s3outposts/client.rb', line 802 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 |
# File 'lib/aws-sdk-s3outposts/client.rb', line 772 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::S3Outposts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-s3outposts' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#create_endpoint(params = {}) ⇒ Types::CreateEndpointResult
Creates an endpoint and associates it with the specified Outpost.
Related actions include:
86 |
# File 'sig/client.rbs', line 86
def create_endpoint: (
|
#delete_endpoint(params = {}) ⇒ Struct
Deletes an endpoint.
Related actions include:
96 |
# File 'sig/client.rbs', line 96
def delete_endpoint: (
|
#list_endpoints(params = {}) ⇒ Types::ListEndpointsResult
Lists endpoints associated with the specified Outpost.
Related actions include:
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
108 |
# File 'sig/client.rbs', line 108
def list_endpoints: (
|
#list_outposts_with_s3(params = {}) ⇒ Types::ListOutpostsWithS3Result
Lists the Outposts with S3 on Outposts capacity for your Amazon Web Services account. Includes S3 on Outposts that you have access to as the Outposts owner, or as a shared user from Resource Access Manager (RAM).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
120 |
# File 'sig/client.rbs', line 120
def list_outposts_with_s3: (
|
#list_shared_endpoints(params = {}) ⇒ Types::ListSharedEndpointsResult
Lists all endpoints associated with an Outpost that has been shared by Amazon Web Services Resource Access Manager (RAM).
Related actions include:
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
132 |
# File 'sig/client.rbs', line 132
def list_shared_endpoints: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
792 793 794 |
# File 'lib/aws-sdk-s3outposts/client.rb', line 792 def waiter_names [] end |