Class: Aws::S3Outposts::Types::Endpoint

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-s3outposts/types.rb

Overview

Amazon S3 on Outposts Access Points simplify managing data access at scale for shared datasets in S3 on Outposts. S3 on Outposts uses endpoints to connect to Outposts buckets so that you can perform actions within your virtual private cloud (VPC). For more information, see Accessing S3 on Outposts using VPC-only access points in the Amazon Simple Storage Service User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_type ⇒ String

The type of connectivity used to access the Amazon S3 on Outposts endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#cidr_block ⇒ String

The VPC CIDR committed by this endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time ⇒ Time

The time the endpoint was created.

Returns:

  • (Time)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#customer_owned_ipv_4_pool ⇒ String

The ID of the customer-owned IPv4 address pool used for the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_arn ⇒ String

The Amazon Resource Name (ARN) of the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#failed_reason ⇒ Types::FailedReason

The failure reason, if any, for a create or delete endpoint operation.

Returns:



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#network_interfaces ⇒ Array<Types::NetworkInterface>

The network interface of the endpoint.

Returns:



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#outposts_id ⇒ String

The ID of the Outposts.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_id ⇒ String

The ID of the security group used for the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_id ⇒ String

The ID of the subnet used for the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC used for the endpoint.

Returns:

  • (String)


175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/aws-sdk-s3outposts/types.rb', line 175

class Endpoint < Struct.new(
  :endpoint_arn,
  :outposts_id,
  :cidr_block,
  :status,
  :creation_time,
  :network_interfaces,
  :vpc_id,
  :subnet_id,
  :security_group_id,
  :access_type,
  :customer_owned_ipv_4_pool,
  :failed_reason)
  SENSITIVE = []
  include Aws::Structure
end